@@ -112,17 +112,19 @@ class Pytifications:
 
     def _check_if_any_callbacks_to_be_called():
         while True:
-            time.sleep(1)
+            time.sleep(3)
             if not Pytifications.am_i_logged_in():
                 continue
             try:
+                print('trying to get callbacks!')
                 res = requests.get('https://pytifications.herokuapp.com/get_callbacks',json={
                     "username":Pytifications._login,
                     "password_hash":hashlib.sha256(Pytifications._password.encode('utf-8')).hexdigest(),
                     "script_id":Pytifications._script_id
                 })
-            except:
-                pass
+            except Exception as e:
+                print(e)
+                continue
             if res.status_code == 200:
                 json = res.json()
                 for item in json:
